@@ -2,38 +2,43 @@
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
  * Copyright (C) 2011, 2012, 2014 Loic J. Duros
+ * Copyright (C) 2014, 2015 Nik Nyby
  *
- * This program is free software: you can redistribute it and/or modify
+ * This file is part of GNU LibreJS.
+ *
+ * GNU LibreJS is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * GNU LibreJS is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see  <http://www.gnu.org/licenses/>.
- *
+ * along with GNU LibreJS.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-var acceptedScripts = require('script_entries/accepted_scripts').acceptedScripts;
+var acceptedScripts = require('../lib/script_entries/accepted_scripts')
+    .acceptedScripts;
 
 exports.testAddAScript = function (assert) {
     var str = "http://www.lduros.net/assets/blah.js";
     var script = {inline: false, contents: str};
-    assert.equal(script.contents, str);
-    assert.equal(acceptedScripts.addAScript('http://www.example.org/', script), true);
+    assert.strictEqual(script.contents, str);
+    assert.strictEqual(
+        acceptedScripts.addAScript('http://www.example.org/', script), true);
     var fetchedScript = acceptedScripts.getScripts('http://www.example.org/');
     assert.ok(fetchedScript);
-    assert.equal(fetchedScript[0].contents, str);
+    assert.strictEqual(fetchedScript[0].contents, str);
 };
 
 exports.testAddAScriptTwice = function (assert) {
     var str = "http://www.lduros.net/assets/blah.js";
     var script = {inline:false, contents: str};
-    assert.equal(acceptedScripts.addAScript('http://www.example.org/', script), false);
+    assert.strictEqual(
+        acceptedScripts.addAScript('http://www.example.org/', script), false);
 };
 
 exports.testIsFound = function (assert) {
@@ -41,7 +46,7 @@ exports.testIsFound = function (assert) {
     var str = "http://www.lduros.net/assets/blah.js";
     var script = {inline:false, contents: str};
     acceptedScripts.addAScript('http://lduros.net/', script);
-    assert.equal(acceptedScripts.isFound(url, script), true);
+    assert.strictEqual(acceptedScripts.isFound(url, script), true);
 };
 
 exports.testIsFoundHash = function (assert) {
@@ -52,8 +57,10 @@ exports.testIsFoundHash = function (assert) {
     // The hash property should be added during addAScript execution.
     var obj = {'inline': true, 'contents': str};
     acceptedScripts.addAScript('http://example.com/', obj);
-    assert.equal(acceptedScripts.scripts['http://example.com/'][acceptedScripts.scripts['http://example.com/'].length -1].hash, hash);
-    assert.equal(acceptedScripts.isFound('http://example.com/', obj), true);
+    assert.strictEqual(
+        acceptedScripts.scripts['http://example.com/'][acceptedScripts.scripts['http://example.com/'].length -1].hash, hash);
+    assert.strictEqual(
+        acceptedScripts.isFound('http://example.com/', obj), true);
 };
 
 require('sdk/test').run(exports);
